import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format
} from 'd3';

Promise.all([
    csv(
      'https://gist.githubusercontent.com/mingliu815/e5f4b3ff7dfeae8a9a2924b121c37468/raw/5ce2802388ba56532e88e8f8e6866dcd877a030c/yelp_topRestaurants_MA_open.csv'
    )
  ]).then(([yelpData]) => {
    var citys = yelpData.reduce((acc, cur) => {
      acc[cur.city] = (acc[cur.city] || 0) + 1;
      return acc;
    }, {});
  
  //console.log(radiusValue)
   let sorted = Object.entries(citys).sort((a, b) => b[1] - a[1]);
   const top10 = sorted.slice(0,10);
  //save this to a new csv file, data.csv
  //console.table(top10)
 }); 
  
const titleText = 'Top Cities with Best Restaurants in Greater Boston';
const xAxisLabelText = 'Number of 4-starts-or-above restaurants on Yelp';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => +d['count'];
  const yValue = d => d.city;
  const margin = { top: 50, right: 40, bottom: 77, left: 120 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight);
  
  g.append('g')
    .call(axisLeft(yScale))
    .selectAll('.domain, .tick line')
      .remove();
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 65)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabelText);
  
  g.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth());
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(titleText);
};

csv('data.csv').then(data => {
  render(data);
});